//	StringParser.h - Simple parser class to read from a string and output the
//					 digits from it.
//  ----------------------------------------------------------------------------
//	This file is part of Motion Composition Tool, a simple application for
//	creating simple abstract animations.
//	Copyright (c) 2007 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//	----------------------------------------------------------------------------

#ifndef STRINGPARSER_H_
#define STRINGPARSER_H_

#include <string>
#include <vector>

///	Struct to hold 4 floats.
struct FourFloats
{
	float x;
	float y;
	float z;
	float r;
};

///	Struct to hold 8 floats.
struct EightFloats
{
	float x[4];
	float y[4];
};

///	Simple parser class to read from a string and output the digits from it.
class StringParser
{
  public:
	///	Constructor.
	/*!
		\param input The string to parse.
	 */
	StringParser(const std::string& input);
	///	Destructor.
	~StringParser();

	///	Returns the number of floats in the string.
	int getNumFloats() const;
	///	Returns the number of FourFloats structures in the string.
	/*!
		This first checks if the number of numbers in the string is a multiple
		of 4.  If not, it will return 0, even if there are numbers in the
		string.
	 */
	int getNumFourFloats() const;
	///	Returns the number of EightFloats structures in the string.
	/*!
		This first checks if the number of numbers in the string is a multiple
		of 8.  If not, it will return 0, even if there are numbers in the
		string.
	 */
	int getNumEightFloats() const;

	///	Returns the indexed number as a float.
	float getFloat(int index = 0) const;
	///	Returns the indexed numbers as a FourFloats structure.
	/*!
		\param index The index of the required FourFloats.  This method assumes
		that numbers contains a multiple of 4 number of numbers.  index is
		the index to the ThreeFloats, not the index to the individual numbers
		stored (i.e. if you passed in an index of 1, that would be calculated
		internally as 4 - pointing to the fifth number stored).
		\return Returns 0 if the index is outwith the numbers vector's limits.
	 */
	FourFloats getFourFloats(int index = 0) const;
	///	Returns the indexed numbers as an EightFloats structure.
	/*!
		\param index The index of the required EightFloats.  This method assumes
		that numbers contains a multiple of 8 number of numbers.  index is
		the index to the ThreeFloats, not the index to the individual numbers
		stored (i.e. if you passed in an index of 1, that would be calculated
		internally as 8 - pointing to the fifth number stored).
		\return Returns 0 if the index is outwith the numbers vector's limits.
	 */
	EightFloats getEightFloats(int index = 0) const;
  private:
	///	Helper method to fill in numbers.
	void fillNumbers(const std::string& input);

	///	vector containing all the numbers read from the input string.
	std::vector<float> numbers;
};

#endif
